@@ -19,11 +19,16 @@ def route(url, name=None):
         return func
     return wrapper
 
-def as_response(**response_kwargs):
+def as_response(dumper=None, **response_kwargs):
     ''' Базовый декоратор response '''
     def decorator(func):
         def wrapper(*args, **kwargs):
-            return Response(func(*args, **kwargs), **response_kwargs)
+            res = func(*args, **kwargs)
+            if not isinstance(res, Response):
+                if dumper:
+                    res = dumper(res)
+                res = Response(res, **response_kwargs)
+            return res
         return wrapper
     return decorator
     
@@ -35,16 +40,10 @@ def as_html(**kwargs):
     ''' Декоратор html-response '''
     return as_response(content_type='text/html', **kwargs)
 
-def as_json(**response_kwargs):
+def as_json(**kwargs):
     ''' Декоратор json_response '''
-    def decorator(func):
-        def wrapper(*args, **kwargs):
-            if 'content_type' not in response_kwargs:
-                response_kwargs['content_type'] = 'application/json'
-            return Response(json.dumps(func(*args, **kwargs),
-                default=lambda v: 'no json serializable'), **response_kwargs)
-        return wrapper
-    return decorator
+    return as_response(dumper=json.dumps,
+        content_type='application/json', **kwargs)
 
 def to_template(fn, **response_kwargs):
     '''
@@ -52,12 +51,14 @@ def to_template(fn, **response_kwargs):
     '''
     def decorator(func):
         def wrapper(rq, *args, **kwargs):
+            res = func(rq, *args, **kwargs)
+            if isinstance(res, Response):
+                return res
             return render_to_response(
-                rq, fn, func(rq, **kwargs), **response_kwargs)
+                rq, fn, res, **response_kwargs)
         return wrapper
     return decorator
 
-
 def anticache(func):
     ''' Декоратор браузерного антикэша '''
     def wrapper(*args, **kwargs):
