@@ -290,8 +290,8 @@ def redirect(url, permanent=False, **kwargs):
     '''
     code = 301 if permanent else 302
     if not url.startswith(('/', 'http://', 'https://')):
-        url = url4(url) or url
-    return Response('', code=code, headers={'Location': url}, **kwargs)
+        url = url4(url, **kwargs) or url
+    return Response('', code=code, headers={'Location': url})
 
 
 HTTP_CODES = {
